@@ -32,6 +32,7 @@ char cheader[128];
 Font *cfont = 0, *chfont = 0, *ccfont = 0; /* normal, highlight and caption font */
 extern Config config;
 extern Sdl sdl;
+extern char gametype_ids[8][64];
 extern char gametype_names[8][64];
 
 /*
@@ -48,7 +49,7 @@ Reset charts
 void chart_reset( Set_Chart *chart )
 {
     int i;
-    memset( chart->entries, 0, sizeof( Chart_Entry ) * CHART_ENTRY_COUNT );
+    memset( chart->entries, 0, sizeof( chart->entries ) );
     for ( i = 0; i < CHART_ENTRY_COUNT; i++ )
         chart_add( chart, "............",  i + 1, 10000 * ( i + 1 ) );
     for ( i = 0; i < CHART_ENTRY_COUNT; i++ )
@@ -145,7 +146,7 @@ int chart_load_from_path( char *path )
 		else {
 			/* old format: load single chart as 'Classic' */
 			fprintf( stderr, "Converting highscore chart as format changed.\n" );
-			chart = chart_set_create( gametype_names[1] );
+			chart = chart_set_create( gametype_ids[1] );
 			chart_read_entries( file, file_name, chart );
 			list_add( charts, chart );
 		}
@@ -153,7 +154,7 @@ int chart_load_from_path( char *path )
     }
     else {
         fprintf( stderr, "Highscore chart doesn't exist in '%s'... creating new one.\n", path );
-		chart = chart_set_create( gametype_names[1] );
+		chart = chart_set_create( gametype_ids[1] );
 		list_add( charts, chart );
     }
     /* test if writing is allowed without changing actual contents */
@@ -315,12 +316,30 @@ void chart_show( Set_Chart *chart, int x, int y, int w, int h )
     int entry_offset; /* y offset of entries */
     Font *font;
     int i;
+    char *cname;
+    
     /* adjust x,y so it's centered */
     x += ( w - chart_w ) / 2;
     y += ( h - chart_h ) / 2;
+    
+	/* FIXME: map chart name (=id) to readable i18n name. would be
+	 * better to use gametype id directly in chart instead of name
+	 * because then we could skip this linear search. but since there
+	 * are not so many charts it does not hurt either... if name cannot
+	 * be mapped, use plain id. */
+	cname = NULL;
+ 	for (i=0;i<GAME_LAST;i++)
+		if (strcmp(chart->name,gametype_ids[i])==0) {
+			cname=gametype_names[i];
+			break;
+		}
+	if (cname==NULL)
+		cname=chart->name;
+    
 	/* title = name of levelset */
     ccfont->align = ALIGN_X_CENTER | ALIGN_Y_TOP;
-    write_text( ccfont, sdl.screen, x + ( chart_w >> 1 ), y,  chart->name, OPAQUE );
+    write_text( ccfont, sdl.screen, x + ( chart_w >> 1 ), y,  cname, OPAQUE );
+    
 	/* caption */
     ccfont->align = ALIGN_X_LEFT | ALIGN_Y_TOP;
     write_text( ccfont, sdl.screen, x, y + ccfont->height + chart_gap, cheader, OPAQUE );
