@@ -82,6 +82,7 @@ void config_reset()
     config.cpu_rot_delay = 100;
     /* controls */
     config.hori_delay = 3;
+    config.vert_delay= 3;
     config.pause_key = SDLK_p;
     config.player1.controls.left = SDLK_LEFT;
     config.player1.controls.right = SDLK_RIGHT;
@@ -191,6 +192,7 @@ void config_load( )
     parser_get_int( pd, "static_background", &config.keep_bkgnd );
     parser_get_int( pd, "smooth_hori", &config.smooth_hori );
     parser_get_int( pd, "hori_delay", &config.hori_delay );
+    parser_get_int( pd, "vert_delay", &config.vert_delay );
     parser_get_int( pd, "pause_key", &config.pause_key );
     parser_get_int( pd, "block_by_block", &config.block_by_block );
     parser_get_int( pd, "motion_mod", &config.motion_mod );
@@ -255,6 +257,7 @@ void config_save( )
         fprintf( file, "static_background%i\n", config.keep_bkgnd );
         fprintf( file, "smooth_hori%i\n", config.smooth_hori );
         fprintf( file, "hori_delay%i\n", config.hori_delay );
+        fprintf( file, "vert_delay%i\n", config.vert_delay );
         fprintf( file, "pause_key%i\n", config.pause_key );
         fprintf( file, "block_by_block%i\n", config.block_by_block );
         fprintf( file, "motion_mod%i\n", config.motion_mod );
