@@ -1083,10 +1083,10 @@ inline void flip_screen()
 /* creates cursor */
 SDL_Cursor* create_cursor( int width, int height, int hot_x, int hot_y, char *source )
 {
-    char *mask = 0, *data = 0;
+    unsigned char *mask = 0, *data = 0;
     SDL_Cursor *cursor = 0;
     int i, j, k;
-    char data_byte, mask_byte;
+    unsigned char data_byte, mask_byte;
     int pot;
 
     /* meaning of char from source:
